@extends('layouts.connected')

@inject('tag_detector', 'App\Services\TagDetectorService)

@section('content')
<div class="container">
    <div class="page-header">
        <h1 class="page-title">
            {{ __('Dashboard') }}
        </h1>
        @if (session('status'))
            <div class="alert alert-success" role="alert">
                {{ session('status') }}
            </div>
        @endif
        @if (session('success'))
            <div class="alert alert-success" role="alert">
                {{ session('success') }}
            </div>
        @endif
        @if (session('errors'))
            <div class="alert alert-danger" role="alert">
                {{ session('errors') }}
            </div>
        @endif
    </div>
    <div class="row flex-fill">
        <div class="col-sm-6 col-lg-3">
            <div class="card p-3">
                <div class="d-flex align-items-center">
                    <span class="stamp stamp-md bg-blue mr-3">
                      <i class="fe fe-activity"></i>
                    </span>
                    <div>
                        <h4 class="m-0">{{ $all_counts }}</h4>
                        <small class="text-muted">{{ __('Jours Écrits') }}</small>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-sm-6 col-lg-3">
            <div class="card p-3">
                <div class="d-flex align-items-center">
                    <span class="stamp stamp-md bg-green mr-3">
                      <i class="fe fe-calendar"></i>
                    </span>
                    <div>
                        <h4 class="m-0">{{ $year_counts }}</h4>
                        <small class="text-muted">{{ __('Cette Année') }}</small>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-sm-6 col-lg-3">
            <div class="card p-3">
                <div class="d-flex align-items-center">
                    <span class="stamp stamp-md bg-red mr-3">
                      <i class="fe fe-grid"></i>
                    </span>
                    <div>
                        <h4 class="m-0">{{ $month_counts }}</h4>
                        <small class="text-muted">{{ __('Ce Mois') }}</small>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-sm-6 col-lg-3">
            <div class="card p-3">
                <div class="d-flex align-items-center">
                    <span class="stamp stamp-md bg-yellow mr-3">
                      <i class="fe fe-image"></i>
                    </span>
                    <div>
                        <h4 class="m-0">{{ $image_counts }}</h4>
                        <small class="text-muted">{{ __('Images Envoyées') }}</small>
                    </div>
                </div>
            </div>
        </div>
        <div class="col-md-12">
            @if($already)
                <div class="alert alert-primary">L'activité du jour a déjà été entrée.</div>
            @endif
            <div class="row @if($already) collapse @endif" id="collapse">
                <div class="col-sm-12">
                    <div class="card">
                        <div class="card-header">
                            <h3 class="card-title">{{ strftime('%B %G', $today->format('U')) }}</h3>
                        </div>
                        <div class="card-body">
                            <form action="@if($already) {{ url('edit') }}@else{{ url('store') }}@endif" method="post" accept-charset="utf-8" enctype="multipart/form-data">
                                @csrf
                                <div class="contact-form">
                                    <div class="form-group">
                                        <label class="control-label col-sm-5" for="message">Quoi de neuf aujourd'hui ?</label>
                                        <div class="col-sm-10">
                                            <div id="app"></div>
                                            <span class="text-danger">{{ $errors->first('message') }}</span>
                                            <input type="file" name="file" id="file" class="input-file">
                                            <label for="file" class="btn btn-tertiary js-labelFile">
                                                <i class="fe fe-upload"></i>
                                                <span class="js-fileName">Choose a file</span>
                                            </label>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <div class="col-sm-offset-2 col-sm-10">
                                            <button type="submit" class="btn btn-primary ml-auto">J'enregistre ma journée</button>
                                        </div>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        @foreach($posts as $post)
            <div class="col-md-6 col-xl-4">
                <div class="card">
                    <div class="card-status bg-blue"></div>
                    <div class="card-header">
                        <h3 class="card-title">{{ ucfirst(\Carbon\Carbon::instance($post->date_post)->diffForHumans()) }}</h3>
                        <div class="card-options">
                            <a href="#" class="card-options-collapse" data-toggle="card-collapse"><i class="fe fe-chevron-up"></i></a>
                            @if($today->format('Y-m-d') === \Carbon\Carbon::instance($post->date_post)->format('Y-m-d'))
                                <button class="btn btn-link" data-toggle="collapse" data-target="#collapse" aria-expanded="true" aria-controls="collapse"><i class="fe fe-edit-2"></i></button>
                                <form action="{{ url('delete') }}" method="post" accept-charset="utf-8">
                                    @csrf
                                    <button class="btn btn-link" data-toggle="card-remove"><i class="fe fe-x"></i></button>
                                </form>
                            @endif
                        </div>
                    </div>
                    <div class="card-body @if($today->format('Y-m-d') === \Carbon\Carbon::instance($post->date_post)->format('Y-m-d')) already @endif ">
                        @if($post->image != '')<p><img src="{{ Auth::user()->getImageData($post) }}"/></p>@endif
                        {!! $tag_detector->linkTagFrom($post->content) !!}
                    </div>
                    <div class="card-footer">
                        {{ \Carbon\Carbon::instance($post->date_post)->format('d F Y') }}
                    </div>
                </div>
            </div>
        @endforeach

    </div>
</div>
@endsection
